@@ -19,10 +19,10 @@
 # define ANDROID_DEFAULT 0
 #endif
 #ifndef TARGET_DEFAULT_ISA_SPEC
-# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_2P2
+# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
 #endif
 #ifndef TARGET_RISCV_ATTRIBUTE
-# define TARGET_RISCV_ATTRIBUTE 0
+# define TARGET_RISCV_ATTRIBUTE 1
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ARCH
 # define TARGET_RISCV_DEFAULT_ARCH rv64gc
